wn.project
==========

.. automodule:: wn.project

.. autofunction:: iterpackages
.. autofunction:: is_package_directory
.. autofunction:: is_collection_directory

.. autoclass:: Package

   .. automethod:: resource_file
   .. automethod:: readme
   .. automethod:: license
   .. automethod:: citation

.. autoclass:: Collection

   .. automethod:: packages
   .. automethod:: readme
   .. automethod:: license
   .. automethod:: citation
